==> medlogics-common-classes-1.1-20251210.123258-520.jar: com/floreantpos/model/ChallanItemDto.java <==
package com.floreantpos.model;

public class ChallanItemDto {
	private String id;
	private String ticketItemId;
	private String ticketItemName;
	private transient double maxItemQuantity;
	private Double itemQuantity;
	private String ticketItemUnit;
	private double unitPrice;
	private String productType;
	private boolean fractionalUnit;
	private String barcode;

	public ChallanItemDto() {
	}

	public ChallanItemDto(String ticketItemId, String ticketItemName, Double itemQuantity, String ticketItemUnit, double unitPrice, String productType,
			boolean fractionalUnit, String barcode) {
		this.ticketItemId = ticketItemId;
		this.ticketItemName = ticketItemName;
		this.itemQuantity = itemQuantity;
		this.ticketItemUnit = ticketItemUnit;
		this.unitPrice = unitPrice;
		this.productType = productType;
		this.fractionalUnit = fractionalUnit;
		this.barcode = barcode;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getTicketItemId() {
		return ticketItemId;
	}

	public void setTicketItemId(String ticketItemId) {
		this.ticketItemId = ticketItemId;
	}

	public String getTicketItemName() {
		return ticketItemName;
	}

	public void setTicketItemName(String ticketItemName) {
		this.ticketItemName = ticketItemName;
	}

	public double getMaxItemQuantity() {
		return maxItemQuantity;
	}

	public void setMaxItemQuantity(double maxItemQuantity) {
		this.maxItemQuantity = maxItemQuantity;
	}

	public Double getItemQuantity() {
		return itemQuantity;
	}

	public void setItemQuantity(Double ticketItemQuantity) {
		this.itemQuantity = ticketItemQuantity;
	}

	public String getTicketItemUnit() {
		return ticketItemUnit;
	}

	public void setTicketItemUnit(String ticketItemUnit) {
		this.ticketItemUnit = ticketItemUnit;
	}

	public double getUnitPrice() {
		return unitPrice;
	}

	public void setUnitPrice(double unitPrice) {
		this.unitPrice = unitPrice;
	}

	public String getProductType() {
		return productType;
	}

	public void setProductType(String productType) {
		this.productType = productType;
	}

	public boolean isFractionalUnit() {
		return fractionalUnit;
	}

	public void setFractionalUnit(boolean fractionalUnit) {
		this.fractionalUnit = fractionalUnit;
	}

	public String getBarcode() {
		return barcode;
	}

	public void setBarcode(String barcode) {
		this.barcode = barcode;
	}

}

==> medlogics-common-classes-2.34.jar: com/floreantpos/model/ChallanItemDto.java <==
package com.floreantpos.model;

public class ChallanItemDto {
	private String id;
	private String ticketItemId;
	private String ticketItemName;
	private transient double maxItemQuantity;
	private Double itemQuantity;
	private String ticketItemUnit;
	private double unitPrice;
	private String productType;
	private boolean fractionalUnit;

	public ChallanItemDto() {
	}

	public ChallanItemDto(String ticketItemId, String ticketItemName, Double itemQuantity, String ticketItemUnit, double unitPrice, String productType,
			boolean fractionalUnit) {
		this.ticketItemId = ticketItemId;
		this.ticketItemName = ticketItemName;
		this.itemQuantity = itemQuantity;
		this.ticketItemUnit = ticketItemUnit;
		this.unitPrice = unitPrice;
		this.productType = productType;
		this.fractionalUnit = fractionalUnit;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getTicketItemId() {
		return ticketItemId;
	}

	public void setTicketItemId(String ticketItemId) {
		this.ticketItemId = ticketItemId;
	}

	public String getTicketItemName() {
		return ticketItemName;
	}

	public void setTicketItemName(String ticketItemName) {
		this.ticketItemName = ticketItemName;
	}

	public double getMaxItemQuantity() {
		return maxItemQuantity;
	}

	public void setMaxItemQuantity(double maxItemQuantity) {
		this.maxItemQuantity = maxItemQuantity;
	}

	public Double getItemQuantity() {
		return itemQuantity;
	}

	public void setItemQuantity(Double ticketItemQuantity) {
		this.itemQuantity = ticketItemQuantity;
	}

	public String getTicketItemUnit() {
		return ticketItemUnit;
	}

	public void setTicketItemUnit(String ticketItemUnit) {
		this.ticketItemUnit = ticketItemUnit;
	}

	public double getUnitPrice() {
		return unitPrice;
	}

	public void setUnitPrice(double unitPrice) {
		this.unitPrice = unitPrice;
	}

	public String getProductType() {
		return productType;
	}

	public void setProductType(String productType) {
		this.productType = productType;
	}

	public boolean isFractionalUnit() {
		return fractionalUnit;
	}

	public void setFractionalUnit(boolean fractionalUnit) {
		this.fractionalUnit = fractionalUnit;
	}

}
